==> wurld-0.3.tar.gz: wurld-0.3/src/SimpleCollidable.cc <==
/*===========================================================================*\

   $Id$

   Copyright (C) 2007 Michael A. Muller

   Permission is granted to use, modify and redistribute this code,
   providing that the following conditions are met:
 
   1) This copyright/licensing notice must remain intact.
   2) If the code is modified and redistributed, the modifications must 
   include documentation indicating that the code has been modified.
   3) The author(s) of this code must be indemnified and held harmless
   against any damage resulting from the use of this code.

   This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
   warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  

\*===========================================================================*/

#include "SimpleCollidable.h"

#include <spug/UnsupportedOperationException.h>
#include "PolyObj.h"
#include "Moveable.h"

SimpleCollidable::SimpleCollidable(const AxisBox &box) : 
   types(axisBox),
   box(box),
   moveable(0),
   priority(0) {
}

void SimpleCollidable::setPoly(const PolyObjPtr &newPolyObj) {
   polyObj = newPolyObj;
   types |= poly;
}

void SimpleCollidable::setAxisBox(const AxisBox &newBox) {
   box = newBox;
}

void SimpleCollidable::setSphere(const Collidable::Sphere &sphere) {
   sphereObj = sphere;
}

int SimpleCollidable::getPriority() const {
   if (priority)
      return priority;
   else 
      return moveable ? 1 : 0;
}

bool SimpleCollidable::checkForCollision(const CollidablePtr &other,
                                         Float &distance
                                         ) const {
   if (moveable)
      return moveable->checkForCollision(other, distance);
   else
      return false;
}

void SimpleCollidable::informOfCollision(const CollidablePtr &other,
				         Float distance
					 ) {
   if (moveable)
      moveable->informOfCollision(other, distance);
}

const Poly &SimpleCollidable::getPoly() const {
   if (!types.includes(poly)) 
      throw spug::UnsupportedOperationException("Poly collidable not defined "
                                                 "for this object."
                                                );
   return *polyObj;
}

AxisBox SimpleCollidable::getAxisBox() const {
   AxisBox result = box;
   if (moveable) {
      Vector pos = moveable->getPosition();
      result.min += pos;
      result.max += pos;
   }
   return result;
}

const Collidable::Sphere &SimpleCollidable::getSphere() const {
   return sphereObj;
}

Vector SimpleCollidable::getVelocity() const {
   if (moveable)
      return moveable->getVelocity();
   else
      return Vector();
}

==> wurld-0.4.tar.gz: wurld-0.4/src/SimpleCollidable.cc <==
/*===========================================================================*\

   $Id$

   Copyright (C) 2007 Michael A. Muller

   Permission is granted to use, modify and redistribute this code,
   providing that the following conditions are met:
 
   1) This copyright/licensing notice must remain intact.
   2) If the code is modified and redistributed, the modifications must 
   include documentation indicating that the code has been modified.
   3) The author(s) of this code must be indemnified and held harmless
   against any damage resulting from the use of this code.

   This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
   warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  

\*===========================================================================*/

#include "SimpleCollidable.h"

#include <spug/UnsupportedOperationException.h>
#include "PolyObj.h"
#include "Moveable.h"

SimpleCollidable::SimpleCollidable(const AxisBox &box) : 
   types(axisBox),
   box(box),
   moveable(0),
   priority(0) {
}

void SimpleCollidable::setPoly(const PolyObjPtr &newPolyObj) {
   polyObj = newPolyObj;
   types |= poly;
}

void SimpleCollidable::setAxisBox(const AxisBox &newBox) {
   box = newBox;
}

void SimpleCollidable::setSphere(const Sphere &newSphere) {
   sphereObj = newSphere;
   types |= sphere;
}

int SimpleCollidable::getPriority() const {
   if (priority)
      return priority;
   else 
      return moveable ? 1 : 0;
}

bool SimpleCollidable::checkForCollision(const CollidablePtr &other,
                                         Float &distance
                                         ) const {
   if (moveable)
      return moveable->checkForCollision(other, distance);
   else
      return false;
}

void SimpleCollidable::informOfCollision(const CollidablePtr &other,
				         Float distance
					 ) {
   if (moveable)
      moveable->informOfCollision(other, distance);
}

const Poly &SimpleCollidable::getPoly() const {
   if (!types.includes(poly)) 
      throw spug::UnsupportedOperationException("Poly collidable not defined "
                                                 "for this object."
                                                );
   return *polyObj;
}

AxisBox SimpleCollidable::getAxisBox() const {
   AxisBox result = box;
   if (moveable) {
      Vector pos = moveable->getPosition();
      result.min += pos;
      result.max += pos;
   }
   return result;
}

Sphere SimpleCollidable::getSphere() const {
   if (moveable)
      return Sphere(sphereObj.center + moveable->getPosition(), 
                    sphereObj.radius
                    );
   else
      return sphereObj;
}

Vector SimpleCollidable::getVelocity() const {
   if (moveable)
      return moveable->getVelocity();
   else
      return Vector();
}
